#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Viewpoint3D(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Viewpoint3D
                | 
                | Represents the 3D viewpoint.
                | The 3D viewpoint is the object that stores data which defines how your objects
                | are seen to enable their display by a 3D viewer. This data includes namely the
                | eye location, also named the origin, the distance from the eye to the target,
                | that is to the looked at point in the scene, the sight, up, and right
                | directions, defining a 3D axis system with the eye location as origin, the
                | projection type chosen among perspective (conic) and parallel (cylindric), and
                | the zoom factor. The right direction is not exposed in a property, and is
                | automatically computed from the sight and up directions.
                | 
                | See also:
                |     CatProjectionMode
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.viewpoint_3d = com_object

    @property
    def field_of_view(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FieldOfView() As double
                | 
                |     Returns or sets the field of view associated with the viewpoint. The field
                |     of view is half of the vertical angle of the viewpoint, expressed in degrees.
                |     This property exists with the perspective (conic) projection type
                |     only.
                | 
                |     Example:
                |         This example retrieves in HalfAngle the field of view associated with
                |         the NiceViewpoint viewpoint.
                | 
                |          HalfAngle = NiceViewpoint.FieldOfView

        :return: float
        :rtype: float
        """

        return self.viewpoint_3d.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value: float):
        """
        :param float value:
        """

        self.viewpoint_3d.FieldOfView = value

    @property
    def focus_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FocusDistance() As double
                | 
                |     Returns or sets the focus distance of the viewpoint. The focus distance
                |     determines the target position, that is the point at which the eye located at
                |     the origin and looking towards the sight direction is looking at. It is
                |     expressed in model units.
                | 
                |     Example:
                |         This example sets the focus distance of the NiceViewpoint viewpoint to
                |         10.
                | 
                |          NiceViewpoint.FocusDistance = 10

        :return: float
        :rtype: float
        """

        return self.viewpoint_3d.FocusDistance

    @focus_distance.setter
    def focus_distance(self, value: float):
        """
        :param float value:
        """

        self.viewpoint_3d.FocusDistance = value

    @property
    def projection_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProjectionMode() As CatProjectionMode
                | 
                |     Returns or sets the projection mode.
                | 
                |     Example:
                |         This example sets the projection mode for the My3DViewer 3D viewer to
                |         catProjectionConic.
                | 
                |          My3DViewer.Viewpoint3D.NavigationStyle = catProjectionConic

        :return: int
        :rtype: int
        """

        return self.viewpoint_3d.ProjectionMode

    @projection_mode.setter
    def projection_mode(self, value: int):
        """
        :param int value:
        """

        self.viewpoint_3d.ProjectionMode = value

    @property
    def zoom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Zoom() As double
                | 
                |     Returns or sets the zoom factor associated with the viewpoint. This
                |     property exists with the parallel (cylindric) projection type
                |     only.
                | 
                |     Example:
                |         This example retrieves in ZoomFactor the zoom factor associated with
                |         the NiceViewpoint viewpoint, tests if it is greater than 2, and if so, sets it
                |         to one and applies it.
                | 
                |          ZoomFactor = NiceViewpoint.Zoom
                |          If ZoomFactor > 2 Then
                |           ZoomFactor = 1
                |           NiceViewpoint.Zoom(ZoomFactor)
                |          End If

        :return: float
        :rtype: float
        """

        return self.viewpoint_3d.Zoom

    @zoom.setter
    def zoom(self, value: float):
        """
        :param float value:
        """

        self.viewpoint_3d.Zoom = value

    def get_origin(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant origin)
                | 
                |     Retrieves the coordinates of the origin of the viewpoint. These coordinates
                |     are returned as an array of 3 Variants (double type).
                | 
                |     Example:
                |         This example retrieves the origin of the NiceViewpoint viewpoint in the
                |         origin variable.
                | 
                |          Dim origin(2)
                |          NiceViewpoint.GetOrigin origin

        :return: tuple
        :rtype: tuple
        """
        vba_function_name = 'get_origin'
        vba_code = """
        Public Function get_origin(viewpoint_3d)
            Dim origin (2)
            viewpoint_3d.GetOrigin origin
            get_origin = origin
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_sight_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSightDirection(CATSafeArrayVariant oSight)
                | 
                |     Gets the components of the sight direction of the viewpoint. The sight
                |     direction is the line passes both by the origin of the viewpoint and by the
                |     target.
                | 
                |     Example:
                |         This example gets the sight direction of the
                |         NiceViewpoint
                | 
                |          Dim sight(2)
                |          NiceViewpoint.GetSightDirection sight

        :return: tuple
        :rtype: tuple
        """
        vba_function_name = 'get_sight_direction'
        vba_code = """
        Public Function get_sight_direction(viewpoint_3d)
            Dim oSight (2)
            viewpoint_3d.GetSightDirection oSight
            get_sight_direction = oSight
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_up_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetUpDirection(CATSafeArrayVariant oUp)
                | 
                |     Gets the components of the up direction of the viewpoint.
                | 
                |     Example:
                |         This example gets the up direction of the
                |         NiceViewpoint.
                | 
                |          Dim up(2)
                |          NiceViewpoint.GetUpDirection up

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_up_direction'
        vba_code = """
        Public Function get_up_direction(viewpoint_3d)
            Dim oUp (2)
            viewpoint_3d.GetUpDirection oUp
            get_up_direction = oUp
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_origin(self, origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutOrigin(CATSafeArrayVariant origin)
                | 
                |     Sets the coordinates of the origin of the viewpoint. These coordinates are
                |     set as an array of 3 Variants (double type).
                | 
                |     Example:
                |         This example sets the origin of the NiceViewpoint viewpoint. to the
                |         point with coordinates (10, 25, 15).
                | 
                |          NiceViewpoint.PutOrigin Array(10, 25, 15)

        :param tuple origin:
        :return: None
        :rtype: None
        """
        return self.viewpoint_3d.PutOrigin(origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_origin'
        # # vba_code = """
        # # Public Function put_origin(viewpoint_3d)
        # #     Dim origin (2)
        # #     viewpoint_3d.PutOrigin origin
        # #     put_origin = origin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_sight_direction(self, o_sight: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutSightDirection(CATSafeArrayVariant oSight)
                | 
                |     Sets the components of the sight direction of the viewpoint. The sight
                |     direction is the line passes both by the origin of the viewpoint and by the
                |     target.
                | 
                |     Example:
                |         This example sets the sight direction of the NiceViewpoint viewpoint to
                |         the direction with components (1.414, 1.414, 0).
                | 
                |          NiceViewpoint.PutSightDirection Array(1.414, 1.414,
                |          0)

        :param tuple o_sight:
        :return: None
        :rtype: None
        """
        return self.viewpoint_3d.PutSightDirection(o_sight)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_sight_direction'
        # # vba_code = """
        # # Public Function put_sight_direction(viewpoint_3d)
        # #     Dim oSight (2)
        # #     viewpoint_3d.PutSightDirection oSight
        # #     put_sight_direction = oSight
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_up_direction(self, o_up: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutUpDirection(CATSafeArrayVariant oUp)
                | 
                |     Sets the components of the up direction of the viewpoint.
                | 
                |     Example:
                |         This example sets the up direction of the NiceViewpoint viewpoint to
                |         the direction with components (0, 0, 1).
                | 
                |          NiceViewpoint.PutUpDirection Array(0, 0, 1)

        :param tuple o_up:
        :return: None
        :rtype: None
        """
        return self.viewpoint_3d.PutUpDirection(o_up)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_up_direction'
        # # vba_code = """
        # # Public Function put_up_direction(viewpoint_3d)
        # #     Dim oUp (2)
        # #     viewpoint_3d.PutUpDirection oUp
        # #     put_up_direction = oUp
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Viewpoint3D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.mec_mod_interfaces.fix_together import FixTogether
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class FixTogethers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FixTogethers
                | 
                | A collection of all the FixTogether objects contained in the
                | product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=FixTogether)
        self.fix_togethers = com_object

    def add(self) -> FixTogether:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As FixTogether
                | 
                |     Creates a new FixTogether and adds it to the FixTogethers
                |     collection.
                | 
                |     Returns:
                |         The created FixTogether 
                |     Example:
                |         The following example creates a FixTogether newFixTogether in the
                |         FixTogether collection.
                | 
                |          Set newFixTogether = fixTogethers.Add

        :return: FixTogether
        :rtype: FixTogether
        """
        return FixTogether(self.fix_togethers.Add())

    def item(self, i_index: cat_variant) -> FixTogether:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As FixTogether
                | 
                |     Returns a FixTogether using its index or its name from the FixTogethers
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the FixTogether to retrieve from the
                |             collection of FixTogether. As a numerics, this index is the rank of the
                |             FixTogether in the collection. The index of the first FixTogether in the
                |             collection is 1, and the index of the last FixTogether is Count. As a string,
                |             it is the name you assigned to the FixTogether using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved FixTogether 
                |     Example:
                |         This example retrieves in thisFixTogether the fifth FixTogether in the
                |         collection and in thatFixTogether the FixTogether named MyFixTogether in the
                |         FixTogether collection of the product product.
                | 
                |          Set fixTogetherColl = product.FixTogethers
                |          Set thisFixTogether = fixTogetherColl.Item(5)
                |          Set thatFixTogether = fixTogetherColl.Item("MyFixTogether")

        :param cat_variant i_index:
        :return: FixTogether
        :rtype: FixTogether
        """
        return FixTogether(self.fix_togethers.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a FixTogether from the FixTogethers collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the FixTogether to remove from the
                |             FixTogethers collection. As a numerics, this index is the rank of the
                |             FixTogether in the collection. The index of the first FixTogether in the
                |             collection is 1, and the index of the last FixTogether is Count. As a string,
                |             it is the name you assigned to the FixTogether using the
                |             
                | 
                |         AnyObject.Name property. 
                | 
                | Example:
                |     This example removes the last FixTogether in the
                |     collection.
                | 
                |      fixTogetherColl.Remove(fixTogetherColl.Count)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.fix_togethers.Remove(i_index)

    def __getitem__(self, n: int) -> FixTogether:
        if (n + 1) > self.count:
            raise StopIteration

        return FixTogether(self.fix_togethers.item(n + 1))

    def __iter__(self) -> Iterator[FixTogether]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'FixTogethers(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapePointOnSurface(Point):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Point
                |                             HybridShapePointOnSurface
                | 
                | Represents the Point on Surface feature objects.
                | Role: Allows to access data of the point feature created with a geodesic
                | distance in a direction to a reference point on a surface
                | 
                | See also:
                |     Length 
                | See also:
                |     Reference 
                | See also:
                |     HybridShapeDirection 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_point_on_surface = com_object

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or Sets the direction from the reference point in which the point
                |     is computed.
                | 
                |     Example
                |     :
                |         This example retrieves in oDirection the direction from the reference
                |         point for PointOnSurface feature.
                | 
                |          Dim oDirection As CATIAHybridShapeDirection
                |          Set oDirection  = PointOnSurface.Direction

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_point_on_surface.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_point_on_surface.Direction = direction.com_object

    @property
    def offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Offset() As Length (Read Only)
                | 
                |     Returns the geodesic length.
                | 
                |     Example
                |     :
                |         This example retrieves in oGeodesicOffset the offset (Geodesic Length)
                |         from the reference point for PointOnSurface feature.
                | 
                |          Dim oGeodesicOffset As CATIAReference
                |          Set oGeodesicOffset  = PointOnSurface.GeodesicOffset

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_point_on_surface.Offset)

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Returns or Sets the reference point.
                |     This data is not mandatory.
                |     If no point is given, the middle point on the surface is
                |     taken.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example
                |     :
                |         This example retrieves in oPointRef the reference point for
                |         PointOnSurface feature.
                | 
                |          Dim oPointRef As CATIAReference
                |          Set oPointRef  = PointOnSurface.PointRef

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_on_surface.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_point_on_surface.Point = reference_point.com_object

    @property
    def surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Surface() As Reference
                | 
                |     Returns or Sets the surface.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example
                |     :
                |         This example retrieves in oSurface the supporting surface for
                |         PointOnSurface feature.
                | 
                |          Dim oSurface As CATIAReference
                |          Set oSurface  = PointOnSurface.Surface

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_on_surface.Surface)

    @surface.setter
    def surface(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_point_on_surface.Surface = reference_surface.com_object

    def __repr__(self):
        return f'HybridShapePointOnSurface(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeSplit(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeSplit
                | 
                | Represents the hybrid shape split feature object.
                | Role: To access data of the hybrid shape split feature. This data
                | includes:
                | 
                |     The element to be cut (surface or curve)
                |     The cutting element ( surface, curve or point)
                |     An orientation to specify which side has to be kept
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_split = com_object

    @property
    def automatic_extrapolation_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AutomaticExtrapolationMode() As boolean
                | 
                |     Gets or sets the automatic extrapolation mode status. AutomaticExtrapolationMode =
                |     TRUE : Automatic extrapolation mode is on. =
                |     FALSE : Automatic extrapolation mode is off.
                |
                |     This example retrieves in AutoExtrapolMode the automatic extrapolation mode status for the Split
                |     hybrid shape feature.
                | 
                |      Dim AutoExtrapolMode As boolean
                |      AutoExtrapolMode = Split.AutomaticExtrapolationMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_split.AutomaticExtrapolationMode

    @automatic_extrapolation_mode.setter
    def automatic_extrapolation_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_split.AutomaticExtrapolationMode = value

    @property
    def both_sides_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BothSidesMode() As boolean
                | 
                |     Gets or sets both sides computation mode.
                |     BothSidesMode
                |     TRUE : Both sides are computed.
                |     FALSE : Both sides are not computed.
                |
                |     This example retrieves in BothSides the both sides computation mode for the Split hybrid shape
                |     feature.
                | 
                |      Dim BothSides As boolean
                |      BothSides = Split.BothSidesMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_split.BothSidesMode

    @both_sides_mode.setter
    def both_sides_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_split.BothSidesMode = value

    @property
    def cutting_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CuttingElem() As Reference
                | 
                |     Returns or sets the cutting element.
                |     Sub-element(s) supported (see Boundary object): Face, TriDimFeatEdge,
                |     BiDimFeatEdge or Vertex.
                | 
                |     Example:
                |         This example retrieves in CuttingElement the cutting element for the
                |         Split hybrid shape feature.
                | 
                |          Dim CuttingElement As Reference
                |          Set CuttingElement = Split.CuttingElem

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_split.CuttingElem)

    @cutting_elem.setter
    def cutting_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_split.CuttingElem = reference_element.com_object

    @property
    def elem_to_cut(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToCut() As Reference
                | 
                |     Returns or sets the element to cut.
                | 
                |     Example:
                |         This example retrieves in Element the element to cut for the Split
                |         hybrid shape feature.
                | 
                |          Dim Element As Reference
                |          Set Element = Split.ElemToCut

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_split.ElemToCut)

    @elem_to_cut.setter
    def elem_to_cut(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_split.ElemToCut = reference_element.com_object

    @property
    def extrapolation_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtrapolationType() As long
                | 
                |     Gets or sets the extrapolation type.
                |     ExtrapolationType = CATGSMExtrapolationType_None(0). =
                |     CATGSMExtrapolationType_Tangent(1). =
                |     CATGSMExtrapolationType_Curvature(2).
                |
                |     This example retrieves in ExtrapolateType the extrapolation type for the Split hybrid shape
                |     feature.

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_split.ExtrapolationType

    @extrapolation_type.setter
    def extrapolation_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_split.ExtrapolationType = value

    @property
    def intersection_computation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IntersectionComputation() As boolean
                | 
                |     Gets or sets Intersection computation mode.
                |     IntersectionComputation =
                |     TRUE : Intersection is computed. =
                |     FALSE : Intersection is not computed.
                |
                |     This example retrieves in Intersection the Intersection computation mode for the Split hybrid
                |     shape feature.
                | 
                |      Dim Intersection As boolean
                |      Intersection = Split.IntersectionComputation

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_split.IntersectionComputation

    @intersection_computation.setter
    def intersection_computation(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_split.IntersectionComputation = value

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the orientation used to compute the split.
                |     Role:
                |     Orientation specifies kept parts of cut feature.
                | 
                |     When splitting a surface by a surface :
                |     - If orientation value is 1: kept parts are specified by the "natural"
                |     normal to the cutting feature
                |     - If orientation value -1: kept parts are specified by the inverse of the
                |     "natural" normal to the cutting feature
                | 
                |     When splitting a surface by a curve :
                |     - If orientation value is 1:
                |       kept parts are specified by the result of the cross product : normal(surface)^tangent(curve)
                |     - If orientation value is -1:
                |       Kept parts are specified by the inverse of the result of the cross product :
                |       normal(surface)^tangent(curve)
                | 
                |     When splitting a curve by a point or a curve (without support specified)
                |     :
                |     - If orientation value is 1: Kept parts are from beginning of the curve to
                |     the first intersection,
                |     and, if there is one, from the second to the third intersection and so on
                |     until the end of the curve.
                |     - If orientation value is -1: Kept parts are from the first intersection to
                |     the second (if there is one),
                |     and, if there is one, from the third to the fourth and so on until the end
                |     of the curve.
                | 
                |     When splitting a curve on support:
                |     - If orientation value is 1:
                |       Kept parts are specified by the result of the cross product :
                |       normal(support surface)^tangent(cutting curve)
                |     - If orientation value is -1:
                |       Kept parts are specified by the inverse of the result of the cross product :
                |       normal(support surface)^tangent(cutting curve)
                | 
                |     When splitting a curve by a surface:
                |     - If orientation value is 1: Kept parts are specified by the inverse of the
                |     normal to the surface
                |     - If orientation value is -1: Kept parts are specified by the normal to the
                |     surface
                | 
                |     Example
                |         This example retrieves in OrientValue the orientation value for the
                |         Split hybrid shape feature.
                | 
                |          Dim OrientValue As long
                |          Set OrientValue = Split.Orientation

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_split.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_split.Orientation = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support element.
                |     This support element may not exist.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in Element the support element for the Split
                |         hybrid shape feature.
                | 
                |          Dim Element As Reference
                |          Set Element = Split.Support

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_split.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_split.Support = reference_support.com_object

    @property
    def volume_result(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As long
                | 
                |     Returns or sets the Result Type.
                |     Result type:
                | 
                |         : 0 -> Surface
                |         : 1 -> Volume
                |         , The resultant split will be volume. If input is element to cut is
                |         volume. 
                | 
                | 
                |     Note: Setting volume result requires GSO License.
                | 
                |     Example: This example retrieves in ResultType the result type for the Split
                |     hybrid shape feature.
                | 
                |      Dim RType As long
                |      Set RType = Split.ResultType

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_split.VolumeResult

    @volume_result.setter
    def volume_result(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_split.VolumeResult = value

    def add_cutting_elem(self, i_elem: Reference, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddCuttingElem(Reference iElem,
                | long iOrientation)
                | 
                |     Adds a cutting feature.
                | 
                |     Parameters:
                | 
                |         iElem
                |             cutting feature 
                |         iOrientation
                |             Orientation iOrientation
                |             1 : SameOrientation
                |             -1 : InvertOrientation
                |             2 : KoOrientation

        :param Reference i_elem:
        :param int i_orientation:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.AddCuttingElem(i_elem.com_object, i_orientation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_cutting_elem'
        # # vba_code = """
        # # Public Function add_cutting_elem(hybrid_shape_split)
        # #     Dim iElem (2)
        # #     hybrid_shape_split.AddCuttingElem iElem
        # #     add_cutting_elem = iElem
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_element_to_keep(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementToKeep(Reference iElement)
                | 
                |     Adds an element to specifications. This element will be
                |     kept.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Element to keep.

        :param Reference i_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.AddElementToKeep(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element_to_keep'
        # # vba_code = """
        # # Public Function add_element_to_keep(hybrid_shape_split)
        # #     Dim iElement (2)
        # #     hybrid_shape_split.AddElementToKeep iElement
        # #     add_element_to_keep = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_element_to_remove(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementToRemove(Reference iElement)
                | 
                |     Adds an element to specifications. This element will be
                |     removed.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Element to remove.

        :param Reference i_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.AddElementToRemove(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element_to_remove'
        # # vba_code = """
        # # Public Function add_element_to_remove(hybrid_shape_split)
        # #     Dim iElement (2)
        # #     hybrid_shape_split.AddElementToRemove iElement
        # #     add_element_to_remove = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_cutting_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCuttingElem(long iRank) As Reference
                | 
                |     Gets the cutting feature at a given index (a point, a curve or a
                |     surface).
                | 
                |     Parameters:
                | 
                |         oElem
                |             cutting feature 
                |         iRank
                |             Index of one of the cutting features

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_split.GetCuttingElem(i_rank))

    def get_intersection(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetIntersection(long iRank) As Reference
                | 
                |     Gets the intersection at a given index.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Intersection 
                |         iRank
                |             Index of one of the intersection features

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_split.GetIntersection(i_rank))

    def get_kept_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetKeptElem(long iRank) As Reference
                | 
                |     Gets the kept feature at a given index.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Kept feature 
                |         iRank
                |             Index of one of the kept features

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_split.GetKeptElem(i_rank))

    def get_nb_cutting_elem(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbCuttingElem() As long
                | 
                |     Gets the number of cutting features.
                | 
                |     Parameters:
                | 
                |         oNbCuttingElem
                |             Number of cutting features

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_split.GetNbCuttingElem()

    def get_nb_elements_to_keep(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbElementsToKeep() As long
                | 
                |     Gets the number of elements to keep.
                | 
                |     Parameters:
                | 
                |         oNbElementsToKeep
                |             Number of elements to keep

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_split.GetNbElementsToKeep()

    def get_nb_elements_to_remove(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbElementsToRemove() As long
                | 
                |     Gets the number of elements to remove.
                | 
                |     Parameters:
                | 
                |         oNbElementsToRemove
                |             Number of elements to remove

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_split.GetNbElementsToRemove()

    def get_orientation(self, i_rank: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOrientation(long iRank) As long
                | 
                |     Gets Orientation used to compute the split.
                | 
                |     Parameters:
                | 
                |         oOrientation
                |             Orientation 
                |         iRank
                |             index of the cutting feature
                |             oOrientation
                |             1 : SameOrientation
                |             -1 : InvertOrientation
                |             2 : KoOrientation

        :param int i_rank:
        :return: int
        :rtype: int
        """
        return self.hybrid_shape_split.GetOrientation(i_rank)

    def get_other_side(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetOtherSide() As Reference
                | 
                |     Gets the other side.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Other side

        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_split.GetOtherSide())

    def get_removed_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRemovedElem(long iRank) As Reference
                | 
                |     Gets the removed feature at a given index.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Removed feature 
                |         iRank
                |             Index of one of the removed features

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_split.GetRemovedElem(i_rank))

    def invert_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertOrientation()
                | 
                |     Inverts the orientation used to compute the split.

        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.InvertOrientation()

    def remove_cutting_elem(self, i_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveCuttingElem(Reference iElem)
                | 
                |     Removes a cutting feature.
                | 
                |     Parameters:
                | 
                |         iElem
                |             cutting feature

        :param Reference i_elem:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.RemoveCuttingElem(i_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_cutting_elem'
        # # vba_code = """
        # # Public Function remove_cutting_elem(hybrid_shape_split)
        # #     Dim iElem (2)
        # #     hybrid_shape_split.RemoveCuttingElem iElem
        # #     remove_cutting_elem = iElem
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_element_to_keep(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToKeep(long iRank)
                | 
                |     Removes an element from specifications.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the kept element.

        :param int i_rank:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.RemoveElementToKeep(i_rank)

    def remove_element_to_remove(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToRemove(long iRank)
                | 
                |     Removes an element from specifications.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the removed element.

        :param int i_rank:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.RemoveElementToRemove(i_rank)

    def set_orientation(self, i_rank: int, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOrientation(long iRank,
                | long iOrientation)
                | 
                |     Sets the orientation used to compute the split.
                | 
                |     Parameters:
                | 
                |         iOrientation
                |             Orientation 
                |         iRank
                |             index of the cutting feature
                |             iOrientation
                |             1 : SameOrientation
                |             -1 : InvertOrientation
                |             2 : KoOrientation

        :param int i_rank:
        :param int i_orientation:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_split.SetOrientation(i_rank, i_orientation)

    def __repr__(self):
        return f'HybridShapeSplit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.geometry_2D import Geometry2D
from pycatia.system_interfaces.system_service import SystemService


class Point2D(Geometry2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             Point2D
                | 
                | Class defining a point in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.point_2d = com_object

    def get_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCoordinates(CATSafeArrayVariant oPoint)
                | 
                |     Returns the coordinates of the point
                | 
                |     Parameters:
                | 
                |         oPoint[0]
                |             The X Coordinate of the point 
                |         oPoint[1]
                |             The Y Coordinate of the point

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_coordinates'
        vba_code = """
        Public Function get_coordinates(point2_d)
            Dim oPoint(1)
            point2_d.GetCoordinates oPoint
            get_coordinates = oPoint
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self, i_x: float, i_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetData(double iX,
                | double iY)
                | 
                |     Modifies the coordinates of the point
                | 
                |     Parameters:
                | 
                |         iX
                |             The X Coordinate of the point 
                |         iY
                |             The Y Coordinate of the point

        :param float i_x:
        :param float i_y:
        :return: None
        :rtype: None
        """
        return self.point_2d.SetData(i_x, i_y)

    def __repr__(self):
        return f'Point2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.geometry_2D import Geometry2D
from pycatia.sketcher_interfaces.line_2D import Line2D
from pycatia.sketcher_interfaces.point_2D import Point2D


class Axis2D(Geometry2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             Axis2D
                | 
                | Interface defining a coordinate system in the 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.axis_2d = com_object

    @property
    def horizontal_reference(self) -> Line2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HorizontalReference() As Line2D (Read Only)
                | 
                |     Returns the 2D coordinate system horizontal axis.

        :return: Line2D
        :rtype: Line2D
        """

        return Line2D(self.axis_2d.HorizontalReference)

    @property
    def origin(self) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Origin() As Point2D (Read Only)
                | 
                |     Returns the 2D coordinate system origin.

        :return: Point2D
        :rtype: Point2D
        """

        return Point2D(self.axis_2d.Origin)

    @property
    def vertical_reference(self) -> Line2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VerticalReference() As Line2D (Read Only)
                | 
                |     Returns the 2D coordinate system vertical axis.

        :return: Line2D
        :rtype: Line2D
        """

        return Line2D(self.axis_2d.VerticalReference)

    def __repr__(self):
        return f'Axis2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.defeaturing_filter import DefeaturingFilter


class DefeaturingFilterWithRange(DefeaturingFilter):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PartInterfaces.DefeaturingFilter
                |                         DefeaturingFilterWithRange
                | 
                | Represents the base object for defeaturing filters which uses range(s) of
                | values
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.defeaturing_filter_with_range = com_object

    def get_maximum_activity(self, i_range_id: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMaximumActivity(CATBSTR iRangeId) As boolean

        :param str i_range_id:
        :return: bool
        :rtype: bool
        """
        return self.defeaturing_filter_with_range.getMaximumActivity(i_range_id)

    def get_maximum_angle(self, i_range_id: str) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMaximumAngle(CATBSTR iRangeId) As Angle

        :param str i_range_id:
        :return: Angle
        :rtype: Angle
        """
        return Angle(self.defeaturing_filter_with_range.getMaximumAngle(i_range_id))

    def get_maximum_length(self, i_range_id: str) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMaximumLength(CATBSTR iRangeId) As Length

        :param str i_range_id:
        :return: Length
        :rtype: Length
        """
        return Length(self.defeaturing_filter_with_range.getMaximumLength(i_range_id))

    def get_maximum_value(self, i_range_id: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMaximumValue(CATBSTR iRangeId) As double

        :param str i_range_id:
        :return: float
        :rtype: float
        """
        return self.defeaturing_filter_with_range.getMaximumValue(i_range_id)

    def get_minimum_activity(self, i_range_id: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMinimumActivity(CATBSTR iRangeId) As boolean
                | 
                |     Returns the minimum or maximum value activity of the filter for the given
                |     range id.
                | 
                |     Parameters:
                | 
                |         iRangeId
                |             The identificator of the range on which the minimum/maximum should
                |             be read - if iRangeId is empty or equal to "Default", takes the default range
                |             as defined by the filter ("RibbonRadius" for FilletFilter, "MainDiameter" for
                |             HoleFilter) - else iRangeId should be chosen among: *
                |             {"RibbonRadius","RibbonAngle","RibbonLength"} for FilletFilter *
                |             {"MainDiameter"} for HoleFilter * any defined and supported range id in case of
                |             a user-defined filter 
                | 
                |     Returns:
                |         oValue The filter minimum/maximum activity for the specified
                |         range
                | 
                |         Example:
                |             The following example returns in theMinActivity the minimum value
                |             activity of filter myFilter for the range myRange:
                | 
                |              Set theMinActivity = myFilter.getMinimumActivity(myRange)

        :param str i_range_id:
        :return: bool
        :rtype: bool
        """
        return self.defeaturing_filter_with_range.getMinimumActivity(i_range_id)

    def get_minimum_angle(self, i_range_id: str) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMinimumAngle(CATBSTR iRangeId) As Angle

        :param str i_range_id:
        :return: Angle
        :rtype: Angle
        """
        return Angle(self.defeaturing_filter_with_range.getMinimumAngle(i_range_id))

    def get_minimum_length(self, i_range_id: str) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMinimumLength(CATBSTR iRangeId) As Length

        :param str i_range_id:
        :return: Length
        :rtype: Length
        """
        return Length(self.defeaturing_filter_with_range.getMinimumLength(i_range_id))

    def get_minimum_value(self, i_range_id: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func getMinimumValue(CATBSTR iRangeId) As double
                | 
                |     Returns the minimum or maximum value of the filter for the given range id,
                |     if defined and active.
                | 
                |     Parameters:
                | 
                |         iRangeId
                |             The identificator of the range on which the minimum/maximum should
                |             be read - if iRangeId is empty or equal to "Default", takes the default range
                |             as defined by the filter ("RibbonRadius" for FilletFilter, "MainDiameter" for
                |             HoleFilter) - else iRangeId should be chosen among: *
                |             {"RibbonRadius","RibbonAngle","RibbonLength"} for FilletFilter *
                |             {"MainDiameter"} for HoleFilter * any defined and supported range id in case of
                |             a user-defined filter 
                | 
                |     Returns:
                |         oValue The filter minimum/maximum value for the specified range if
                |         defined and active ELSE the method FAILS (to avoid this,
                |         getMinimumValueActivity/getMaximumValueActivity can be called prior to calling
                |         getMinimumValue/getMaximumValue) Signature with double works for angles as well
                |         as for lengths / EXPRESSED in MODEL UNIT (mm/deg) Signatures with CATIALength
                |         or CATIAAngle must be used with care and will fail if the range nature and the
                |         expected type are incompatible
                | 
                |         Example:
                |             The following example returns in theMinValue the minimum value of
                |             filter myFilter for the range myRange:
                | 
                |              theMinValue = myFilter.getMinimumValue(myRange)
                | 
                |             The following example returns in theMinAngle the minimum value as
                |             an angle of filter myFilter for the range myRange:
                | 
                |              Set theMinAngle = myFilter.getMinimumAngle(myRange)
                | 
                |             The following example returns in theMaxLength the maximum value as
                |             a length of filter myFilter for the range myRange:
                | 
                |              Set theMaxLength = myFilter.getMaximumLength(myRange)

        :param str i_range_id:
        :return: float
        :rtype: float
        """
        return self.defeaturing_filter_with_range.getMinimumValue(i_range_id)

    def set_maximum_activity(self, i_range_id: str, i_value: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub setMaximumActivity(CATBSTR iRangeId,
                | boolean iValue)

        :param str i_range_id:
        :param bool i_value:
        :return: None
        :rtype: None
        """
        return self.defeaturing_filter_with_range.setMaximumActivity(i_range_id, i_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_maximum_activity'
        # # vba_code = """
        # # Public Function set_maximum_activity(defeaturing_filter_with_range)
        # #     Dim iRangeId (2)
        # #     defeaturing_filter_with_range.setMaximumActivity iRangeId
        # #     set_maximum_activity = iRangeId
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_maximum_value(self, i_range_id: str, i_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub setMaximumValue(CATBSTR iRangeId,
                | double iValue)

        :param str i_range_id:
        :param float i_value:
        :return: None
        :rtype: None
        """
        return self.defeaturing_filter_with_range.setMaximumValue(i_range_id, i_value)

    def set_minimum_activity(self, i_range_id: str, i_value: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub setMinimumActivity(CATBSTR iRangeId,
                | boolean iValue)
                | 
                |     Sets the defeaturing minimum or maximum value activity of the filter for
                |     the given range id.
                | 
                |     Parameters:
                | 
                |         iRangeId
                |             The identificator of the range on which the minimum/maximum should
                |             be read - if iRangeId is empty or equal to "Default", takes the default range
                |             as defined by the filter ("RibbonRadius" for FilletFilter, "MainDiameter" for
                |             HoleFilter) - else iRangeId should be chosen among: *
                |             {"RibbonRadius","RibbonAngle","RibbonLength"} for FilletFilter *
                |             {"MainDiameter"} for HoleFilter * any defined and supported range id in case of
                |             a user-defined filter 
                |         iValue
                |             The filter minimum/maximum activity for the specified
                |             range
                | 
                |             Example:
                |                 The two following examples set theMaxActivity as the maximum
                |                 value activity of filter myFilter for the range
                |                 myRange:
                | 
                |                  Call myFilter.setMaximumActivity(myRange,theMaxActivity)
                |                  myFilter.setMaximumActivity myRange
                |                  theMaxActivity

        :param str i_range_id:
        :param bool i_value:
        :return: None
        :rtype: None
        """
        return self.defeaturing_filter_with_range.setMinimumActivity(i_range_id, i_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_minimum_activity'
        # # vba_code = """
        # # Public Function set_minimum_activity(defeaturing_filter_with_range)
        # #     Dim iRangeId (2)
        # #     defeaturing_filter_with_range.setMinimumActivity iRangeId
        # #     set_minimum_activity = iRangeId
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_minimum_value(self, i_range_id: str, i_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub setMinimumValue(CATBSTR iRangeId,
                | double iValue)
                | 
                |     Sets the minimum or maximum value of the filter for the given range id.
                |     Forces the activation of the minimum or maximum value if not the case
                |     yet.
                | 
                |     Parameters:
                | 
                |         iRangeId
                |             The identificator of the range on which the minimum/maximum should
                |             be read - if iRangeId is empty or equal to "Default", takes the default range
                |             as defined by the filter ("RibbonRadius" for FilletFilter, "MainDiameter" for
                |             HoleFilter) - else iRangeId should be chosen among: *
                |             {"RibbonRadius","RibbonAngle","RibbonLength"} for FilletFilter *
                |             {"MainDiameter"} for HoleFilter * any defined and supported range id in case of
                |             a user-defined filter 
                |         iValue
                |             The filter minimum/maximum value for the specified range / MUST BE
                |             EXPRESSED in MODEL UNIT (mm/deg) iValue must be consistent with the other value
                |             if defined and active - new minimum iValue must be smaller than existing active
                |             maximum value if any - new maximum iValue must be larger than existing active
                |             minimum value if any ELSE the method FAILS
                | 
                |             Example:
                |                 The two following examples set theMaxValue as the maximum value
                |                 of filter myFilter for the range myRange:
                | 
                |                  Call
                |                  myFilter.setMaximumValue(myRange,theMaxValue)
                |                  myFilter.setMaximumValue myRange theMaxValue

        :param str i_range_id:
        :param float i_value:
        :return: None
        :rtype: None
        """
        return self.defeaturing_filter_with_range.setMinimumValue(i_range_id, i_value)

    def __repr__(self):
        return f'DefeaturingFilterWithRange(name="{ self.name }")'



#! /usr/bin/python3.9

import csv
import os
import time

from typing import Generator

from pycatia.mec_mod_interfaces.part import Part

unit_conversion = {
    'mm': 1,
    'cm': 10,
    'm': 1000,
    'km': 1000000,
    'in': 25.4,
    'mile': 1.609344e+6,
}


def convert_units(number: str, unit: str) -> float:
    """

    Convert input 'length' from unit to millimeters.

    :param number:
    :param str unit: A string representing the unit 'mm', 'in', 'cm', 'm', 'mile', 'km'
    :return:
    """

    try:
        n = float(number)
    except ValueError:
        raise FloatingPointError("Input {number} can not be converted to float(). Check csv data.")

    try:
        return float(n * unit_conversion[unit])
    except KeyError:
        raise KeyError(f'Unit {unit} is not currently supported.')


def csv_reader(file_name: str, units: str, delimiter: str = ',') -> Generator[dict, None, None]:
    """
    | Reads contents of csv file and returns a generator object containing tuples in the format:
    | [
    |     (
    |         str(<point_name>),
    |         int(X coordinate),
    |         int(Y coordinate),
    |         int(Z coordinate)
    |     ),
    | ]

    :param file_name: full path to csv file.
    :param str units:
    :param delimiter:
    :return: generator()
    """

    if not os.path.isfile(file_name):
        raise FileNotFoundError('Check file exists.')

    with open(file_name) as file:
        csv_file = csv.reader(file, delimiter=delimiter)
        for line in csv_file:
            point = {'name': line[0],
                     'x': convert_units(line[1], units),
                     'y': convert_units(line[2], units),
                     'z': convert_units(line[3], units)}
            yield point


def create_points(part: Part, file_name: str, units: str = 'mm', geometry_set_name: str = 'New_Points') -> None:
    """
    Parses a csv file in the format defined in :func:`~csv_reader` and populates the geometry_set_name with new
    points. Once complete the part is updated.

    :param Part part:
    :param str file_name: full path to csv file.
    :param str units: length units of csv_file eg 'in'
    :param str geometry_set_name: name of new geometrical set in which to add points.
    :return:
    """

    points = csv_reader(file_name, units)

    geometrical_set = part.hybrid_bodies.add()
    geometrical_set.name = geometry_set_name

    hsf = part.hybrid_shape_factory

    for point in points:
        start = time.time()
        new_point = hsf.add_new_point_coord(point['x'], point['y'], point['z'])
        geometrical_set.append_hybrid_shape(new_point)
        end = time.time()
        time_taken = end - start
        print(f"Added point: {point['name']}. Time taken = {round(time_taken, 3)} seconds", end="\r")

    part.update()



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.point import Point
from pycatia.in_interfaces.reference import Reference


class HybridShapePointCenter(Point):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Point
                |                             HybridShapePointCenter
                | 
                | Represents the hybrid shape PointCenter feature object.
                | Role: To access the data of the hybrid shape PointCenter feature object. It has
                | been created by the CATIAHybridShapeFactory. This data
                | includes:
                | 
                |     The circle, ellipsa element 
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_point_center = com_object

    @property
    def element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Element() As Reference
                | 
                |     Returns or sets the circle, ellipse or sphere.
                |     Sub-element(s) supported (see Boundary object): Edge.
                | 
                |     Example
                |     :
                |         This example retrieves in Ref_Circle the center point for the
                |         PointCenter hybrid shape feature.
                | 
                |          Dim Ref_Circle As Reference
                |          Set Ref_Circle = PointCenter.Element

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_point_center.Element)

    @element.setter
    def element(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_point_center.Element = reference_element.com_object

    def __repr__(self):
        return f'HybridShapePointCenter(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCylinder(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCylinder
                | 
                | Represents the hybrid shape Cylinder feature object.
                | Role: To access the data of the hybrid shape Cylinder feature object. This data
                | includes:
                | 
                |     The center of the Cylinder
                |     The Radius of the Cylinder
                |     Length of Cylinder in the given extrusion direction
                |     Length of Cylinder opposite to extrusion direction
                |     Direction of extrusion for cylinder.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCylinder
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_cylinder = com_object

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the center of the cylinder object.
                | 
                |     Example:
                |         This example retrieves in CylinderCenter the center of the Cylinder,
                |         for the Cylinder hybrid shape feature.
                | 
                |          Dim CylinderCenter As Reference 
                |          Set CylinderCenter = Cylinder.Center

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_cylinder.Center)

    @center.setter
    def center(self, reference_center: Reference):
        """
        :param Reference reference_center:
        """

        self.hybrid_shape_cylinder.Center = reference_center.com_object

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or sets the direction of the cylinder object.
                | 
                |     Example:
                |         This example retrieves in CylinderDirection the direction of extrusion
                |         of the Cylinder, for the Cylinder hybrid shape
                |         feature.
                | 
                |          Dim CylinderDirection As HybridShapeDirection 
                |          Set CylinderDirection = Cylinder.Direction

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_cylinder.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_cylinder.Direction = direction.com_object

    @property
    def length1(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Length1() As Length
                | 
                |     Returns or sets the length of the cylinder object in the given extrusion
                |     direction.
                | 
                |     Example:
                |         This example retrieves in CylinderLength1 the length of the Cylinder in
                |         the given extrusion direction, for the Cylinder hybrid shape
                |         feature.
                | 
                |          Dim CylinderLength1 As Length
                |          Set CylinderLength1 = Cylinder.Length1

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_cylinder.Length1)

    @length1.setter
    def length1(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_cylinder.Length1 = length.com_object

    @property
    def length2(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Length2() As Length
                | 
                |     Returns or sets the length of the cylinder object in the opposite direction
                |     of given extrusion direction.
                | 
                |     Example:
                |         This example retrieves in CylinderLength2 the length of the Cylinder in
                |         the opposite direction of the given extrusion direction, for the Cylinder
                |         hybrid shape feature.
                | 
                |          Dim CylinderLength2 As Length
                |          Set CylinderLength2 = Cylinder.Length2

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_cylinder.Length2)

    @length2.setter
    def length2(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_cylinder.Length2 = length.com_object

    @property
    def orientation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation(boolean iOrientation)
                | 
                |     Returns or sets the the inversion of extrusion direction.
                | 
                |     Example:
                |         This example retrieves in IsInverted the inversion status of extrusion
                |         direction for the Cylinder hybrid shape feature.
                | 
                |          Dim IsInverted As boolean
                |          Set IsInverted = Cylinder.Orientation

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_cylinder.Orientation

    @orientation.setter
    def orientation(self, value: bool):
        """
        :param boo value:
        """

        self.hybrid_shape_cylinder.Orientation = value

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length
                | 
                |     Returns or sets the radius of the cylinder object.
                | 
                |     Example:
                |         This example retrieves in CylinderRadius the radius of the Cylinder,
                |         for the Cylinder hybrid shape feature.
                | 
                |          Dim CylinderRadius As Length
                |          Set CylinderRadius = Cylinder.Radius

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_cylinder.Radius)

    @radius.setter
    def radius(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_cylinder.Radius = length.com_object

    @property
    def symmetrical_extension(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SymmetricalExtension() As boolean
                | 
                |     Gets or Sets the symmetrical extension of Cylinder (Length 2 = -Length 1).
                | 
                |     Parameters:
                | 
                |         iSym
                |             Symetry flag

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_cylinder.SymmetricalExtension

    @symmetrical_extension.setter
    def symmetrical_extension(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_cylinder.SymmetricalExtension = value

    def invert_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertOrientation()
                | 
                |     Inverts the Orientation of Cylinder object.
                | 
                |     Example:
                |         This example inverts the orientation for the Cylinder hybrid shape
                |         feature.
                | 
                |          Cylinder.InvertOrientation

        :return: None
        :rtype: None
        """
        return self.hybrid_shape_cylinder.InvertOrientation()

    def __repr__(self):
        return f'HybridShapeCylinder(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.space_analyses_interfaces.conflict import Conflict
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Conflicts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Conflicts
                | 
                | A collection of all Conflict objects currently detected by a Clash
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.conflicts = com_object

    def item(self, i_index: cat_variant) -> Conflict:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Conflict
                | 
                |     Returns a Conflict object using its index from the Conflicts
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the Conflict object to retrieve from the collection of
                |             Conflicts. As a numerics, this index is the rank of the Conflict in the
                |             collection. The index of the first Conflict in the collection is 1, and the
                |             index of the last Conflict is Count. 
                | 
                |     Example:
                | 
                |              This example retrieves in ThisConflict the ninth
                |              Conflict
                |             from the TheConflicts collection. 
                |             
                | 
                |             Dim ThisConflict As Conflict
                |             Set ThisConflict = TheConflicts.Item(9)

        :param cat_variant i_index:
        :return: Conflict
        :rtype: Conflict
        """
        return Conflict(self.conflicts.Item(i_index))

    def __getitem__(self, n: int) -> Conflict:
        if (n + 1) > self.count:
            raise StopIteration

        return Conflict(self.conflicts.item(n + 1))

    def __iter__(self) -> Iterator[Conflict]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Conflicts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve_2D import Curve2D
from pycatia.system_interfaces.system_service import SystemService


class Line2D(Curve2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Line2D
                | 
                | Class defining a line in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.line_2d = com_object

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Returns the unit-vector pointing in the direction of the
                |     line.
                | 
                |     Parameters:
                | 
                |         oDirection[0]
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         oDirection[1]
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_direction'
        vba_code = """
        Public Function get_direction(line2_d)
            Dim oDirection(2)
            line2_d.GetDirection oDirection
            get_direction = oDirection
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns a point lying on the line
                | 
                |     Parameters:
                | 
                |         oPoint[0]
                |             The X Coordinate of a point lying on the line 
                |         oPoint[1]
                |             The Y Coordinate of a point lying on the line

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_origin'
        vba_code = """
        Public Function get_origin(line2_d)
            Dim oOrigin(1)
            line2_d.GetOrigin oOrigin
            get_origin = oOrigin
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self, i_x: float, i_y: float, i_x_direction: float, i_y_direction: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetData(double iX,
                | double iY,
                | double iXDirection,
                | double iYDirection)
                | 
                |     Modifies the caracteristics of the infinite line
                | 
                |     Parameters:
                | 
                |         iX
                |             The X Coordinate of a point lying on the line 
                |         iY
                |             The Y Coordinate of a point lying on the line 
                |         iXDirection
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         iYDirection
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line

        :param float i_x:
        :param float i_y:
        :param float i_x_direction:
        :param float i_y_direction:
        :return: None
        :rtype: None
        """
        return self.line_2d.SetData(i_x, i_y, i_x_direction, i_y_direction)

    def __repr__(self):
        return f'Line2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DynLicenseSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DynLicenseSettingAtt
                | 
                | Interface to handle the dynamic licensing settings.
                | Role: This interface is implemented by a component which represents the
                | controller of the dynamic Licenses.
                | To access this property page:
                | Click the Options command in the Tools menu
                | Click General
                | Click the Shareable Products Property Page
                | 
                | This interface defines:
                | A method to lock/unlock each parameter
                | A method to retrieve the information concerning each parameter
                | Note that when a license is selected, no information is written in the
                | settings, only the lock status is written in the settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dyn_license_setting_att = com_object

    def get_license(self, i_license):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicense(CATBSTR iLicense) As CATBSTR
                | 
                |     The method is not relevant for the settings.
                |     Role: The method is not relevant for the settings, because a dynamic
                |     license is only taken in account for the current session. That is why
                |     GetLicense() does not appears in the dump, even when GetLicenseInfo() appears.
                |     The output oValue will always be "".
                | 
                |     Parameters:
                | 
                |         iLicense
                |             the name of the License. 
                | 
                |     Returns:
                |         the value of the License.
                |         License ""

        :param str i_license:
        :return: str
        """
        return str(self.dyn_license_setting_att.GetLicense(i_license))

    def get_license_info(self, i_license, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicenseInfo(CATBSTR iLicense,
                | CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves the state of a given License.
                |     Role: Retrieves the state of a given License. It it is used to get the lock
                |     status of a specific license. When the license is locked, it means that an
                |     administrator has locked the attribute. It does not means that an administrator
                |     has changed the value of the license.
                | 
                |     Parameters:
                | 
                |         iLicense:
                |             the name of the License. 
                |         ioAdminLevel:
                |             Level of administrator. 
                |         ioLocked:
                |             Locked/Unlocked. 
                | 
                |     Returns:
                |         False.
                |         Refer to SettingController for a detailed description.
                |         Dump information:
                |         Parameter 1 : the name of the License.
                |         Parameter 2 : "Default value".
                |         Parameter 3 : locking state of the licenses Unlocked / Locked / Locked at Admin Level j.
                |         Return value : Always false, because the status of the license is not modified, only the lock
                |           status is modified.

        :param str i_license:
        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.dyn_license_setting_att.GetLicenseInfo(i_license, io_admin_level, io_locked)

    def get_licenses_list(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicensesList() As CATSafeArrayVariant
                | 
                |     Retrieves the List of the Licenses.
                |     Role: Retrieves the list of the locked Licenses. There is no
                |     SetLicenseList() because the list is initialized using
                |     LUM.
                | 
                |     Returns:
                |         The array of Licenses.

        :return: tuple
        """
        return tuple(self.dyn_license_setting_att.GetLicensesList())

    def get_licenses_list_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicensesListInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the LicensesList setting locking state (global
                |     lock for the LicensesList).
                |     Role: Retrieves information about the LicensesList setting locking state
                |     (global lock for the LicensesList) It is used to get the lock status of the
                |     List of the Licenses. If the LicenseList is locked all the licenses are locked.
                |     When the licenses are locked, it means that an administrator has locked the
                |     attribute. It does not means that an administrator has changed the value of the
                |     attribute. The value of the setting is not updatable because it refers to a
                |     lock on a list. That is why the return value is false.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel:
                |             Level of administrator. 
                |         ioLocked:
                |             Locked/Unlocked. 
                | 
                |     Returns:
                |         False.
                |         Parameter values in dump:
                |         Parameter 1 : "Value taken in case of reset" : useless. Default value: "Default value".
                |         Parameter 2 : "Locking state" value : unlocked / locked / locked at Admin Level n
                |         Parameter 3 : "Returned value" : useless, default value : False
                | 
                |         Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.dyn_license_setting_att.GetLicensesListInfo(io_admin_level, io_locked)

    def set_license_lock(self, i_license, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetLicenseLock(CATBSTR iLicense,
                | boolean iLock)
                | 
                |     Locks or unlocks the License setting parameter.
                |     Role: Locks or unlocks the given License if the operation is allowed in the
                |     current administrated environment.
                | 
                |     Parameters:
                | 
                |         iLicense:
                |             the name of the License. 
                |         iLock
                |             the locking operation to be performed:
                |             True: to lock the parameter.
                |             False: to unlock the parameter.
                |             Refer to 
                | 
                |         SettingController for a detailed description.

        :param str i_license:
        :param bool i_lock:
        :return: None
        """
        return self.dyn_license_setting_att.SetLicenseLock(i_license, i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_license_lock'
        # # vba_code = """
        # # Public Function set_license_lock(dyn_license_setting_att)
        # #     Dim iLicense (2)
        # #     dyn_license_setting_att.SetLicenseLock iLicense
        # #     set_license_lock = iLicense
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_licenses_list_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetLicensesListLock(boolean iLock)
                | 
                |     Locks or unlocks the LicensesList setting parameter.
                |     Role: Locks or unlocks the parameter describing the list of installed
                |     licenses, if the operation is allowed in the current administrated environment.
                |     When the LicenseList is locked all the licenses are locked. When the
                |     LicenseList is unlocked all the licenses are unlocked.
                | 
                |     Parameters:
                | 
                |         iLock
                |             the locking operation to be performed:
                |             True: to lock the parameter.
                |             False: to unlock the parameter.
                |             Refer to 
                | 
                |         SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.dyn_license_setting_att.SetLicensesListLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_licenses_list_lock'
        # # vba_code = """
        # # Public Function set_licenses_list_lock(dyn_license_setting_att)
        # #     Dim iLock (2)
        # #     dyn_license_setting_att.SetLicensesListLock iLock
        # #     set_licenses_list_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DynLicenseSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
from pycatia.mec_mod_interfaces.shape import Shape


class Translate(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         Translate
                | 
                | Represents the hybrid shape translate feature object.
                | This solid feature is created from an underlying HybridShapeTranslate
                | aggregated by the Translate. Role: To access the data of the hybrid shape
                | translate feature object. This data includes:
                | 
                |     The element to translate
                |     The translation direction
                |     The translation distance and its value
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.translate = com_object

    @property
    def hybrid_shape(self) -> HybridShape:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridShape() As HybridShape (Read Only)
                | 
                |     Gets the underlying HybridShapeTranslate.
                | 
                |     Example:
                |         The following example explains how to retrieve the underlying
                |         HybridShape Translate
                | 
                |           Dim oHybridShape as AnyObject
                |           Set oHybridShape=oTranslate.HybridShape
                |           oHybridShape.ElemToTranslate = reference1

        :return: HybridShape
        :rtype: HybridShape
        """

        return HybridShape(self.translate.HybridShape)

    def __repr__(self):
        return f'Translate(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
from pycatia.mec_mod_interfaces.hybrid_shapes import HybridShapes
from pycatia.mec_mod_interfaces.sketches import Sketches
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.mec_mod_interfaces.bodies import Bodies
    from pycatia.mec_mod_interfaces.hybrid_bodies import HybridBodies

class HybridBody(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     HybridBody
                | 
                | The object is a hybrid body.
                | The hybrid body manages a set of geometric elements, a set of hybrid shapes, a
                | set of bodies and a set of hybrid bodies.
                | It belongs to the HybridBodies collection of a Part or @ref CATIABody or
                | HybridBody object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_body = com_object

    @property
    def bodies(self) -> 'Bodies':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Bodies() As Bodies (Read Only)
                | 
                |     Returns the hybrid body's Bodies collection.
                | 
                |     Example:
                |         The following example returns in bodyColl the collection of bodies of
                |         the hybrid body hybridBody :
                | 
                |          Set bodyColl = hybridBody.Bodies

        :return: Bodies
        :rtype: Bodies
        """
        from pycatia.mec_mod_interfaces.bodies import Bodies
        return Bodies(self.hybrid_body.Bodies)

    @property
    def geometric_elements(self) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property GeometricElements() As GeometricElements (Read
                | Only)
                | 
                |     Returns the list of geometrical elements included in the hybrid
                |     body.
                | 
                |     Returns:
                |         oGeometricElements The list of geometric elements in the hybrid body
                |         (@see CATIAGeometricElements
                |         for more information).
                | 
                |         Example:
                |             The following example returns in geometricElements the list
                |             of
                |             geometrical elements in the Hybrid body
                |             hybridBody:
                | 
                |              Dim geometricElements As GeometricElements
                |              Set geometricElements = hybridBody.GeometricElements

        :return: GeometricElements
        :rtype: GeometricElements
        """

        return GeometricElements(self.hybrid_body.GeometricElements)

    @property
    def hybrid_bodies(self) -> 'HybridBodies':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridBodies() As HybridBodies (Read Only)
                | 
                |     Returns the hybrid body's HybridBodies collection.
                | 
                |     Example:
                |         The following example returns in hybridBodyColl the collection of
                |         hybrid bodies of the hybrid body hybridBody :
                | 
                |          Set hybridBodyColl = hybridBody.HybridBodies

        :return: HybridBodies
        :rtype: HybridBodies
        """
        from pycatia.mec_mod_interfaces.hybrid_bodies import HybridBodies
        return HybridBodies(self.hybrid_body.HybridBodies)

    @property
    def hybrid_shapes(self) -> HybridShapes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridShapes() As HybridShapes (Read Only)
                | 
                |     Returns the list of hybrid shapes included in the hybrid
                |     body.
                | 
                |     Returns:
                |         oHybridShapes The list of hybrid shapes in the hybrid body (@see
                |         CATIAHybridShapes
                |         for more information).
                | 
                |         Example:
                |             The following example returns in hybridShapes the list
                |             of
                |             hybrid shapes in the hybrid body hybridBody:
                | 
                |              Dim hybridShapes As HybridShapes
                |              Set hybridShapes = hybridBody.HybridShapes

        :return: HybridShapes
        :rtype: HybridShapes
        """

        return HybridShapes(self.hybrid_body.HybridShapes)

    @property
    def hybrid_sketches(self) -> Sketches:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridSketches() As Sketches (Read Only)
                | 
                |     Returns the hybrid body's Sketches collection. These sketches are those
                |     inside the hybrid body at all levels.
                | 
                |     Example:
                |         The following example returns in skColl the collection of sketches of a
                |         hybrid body :
                | 
                |          Set skColl = hybridBody.HybridSketches

        :return: Sketches
        :rtype: Sketches
        """

        return Sketches(self.hybrid_body.HybridSketches)

    def append_hybrid_shape(self, i_hybrid_shape: HybridShape) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AppendHybridShape(HybridShape iHybridShape)
                | 
                |     Appends a hybrid shape to the hybrid body.
                | 
                |     Parameters:
                | 
                |         iHybriShape
                |             The hybrid shape to append. 
                | 
                |     Example:
                |         This example appends the hybrid shape hybridShape to the hybrid body
                |         hybridBody:
                | 
                |          hybridBody.AppendHybridShape (hybridShape)

        :param HybridShape i_hybrid_shape:
        :return: None
        :rtype: None
        """
        return self.hybrid_body.AppendHybridShape(i_hybrid_shape.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_hybrid_shape'
        # # vba_code = """
        # # Public Function append_hybrid_shape(hybrid_body)
        # #     Dim iHybridShape (2)
        # #     hybrid_body.AppendHybridShape iHybridShape
        # #     append_hybrid_shape = iHybridShape
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def append_hybrid_shapes(self, shapes):
        """
        :param list(HybridShape) shapes:
        :return:
        """
        for shape in shapes:
            self.append_hybrid_shape(shape)

    def __repr__(self):
        return f'HybridBody(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.camera import Camera
from pycatia.in_interfaces.viewpoint_3d import Viewpoint3D


class Camera3D(Camera):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Camera
                |                         Camera3D
                | 
                | Represents a 3D camera.
                | The 3D camera stores a 3D viewpoint, that is a Viewpoint3D
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.camera_3d = com_object

    @property
    def viewpoint3_d(self) -> Viewpoint3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Viewpoint3D() As Viewpoint3D
                | 
                |     Returns or sets the 3D viewpoint of a 3D camera.
                | 
                |     Example:
                |         Assume the active window is a SpecsAndGeomWindow object. This example
                |         retrieves the Viewpoint3D of the active 3D viewer and creates from it a
                |         Camera3D you handle using the MyCamera variable. Then the camera zoom is set to
                |         2, and the camera's viewpoint is assigned to the active
                |         viewer.
                | 
                |          Dim MyCamera As Camera3D
                |          Set MyCamera = CATIA.ActiveWindow.ActiveViewer.NewCamera()
                |          MyCamera.Viewpoint3D.Zoom = 2
                |          CATIA.ActiveWindow.ActiveViewer.Viewpoint3D = MyCamera.Viewpoint3D

        :return: Viewpoint3D
        :rtype: Viewpoint3D
        """

        return Viewpoint3D(self.camera_3d.Viewpoint3D)

    @viewpoint3_d.setter
    def viewpoint3_d(self, value: Viewpoint3D):
        """
        :param Viewpoint3D value:
        """

        self.camera_3d.Viewpoint3D = value

    def __repr__(self):
        return f'Camera3D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeProject(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeProject
                | 
                | Represents the hybrid shape project feature object.
                | Role: To access data of the hybrid shape project feature. The data
                | includes:
                | 
                |     The element to project which is a point or a curve
                |     The support element which is a curve or a surface
                |     The projection type ( normal or along a direction)
                |     The projection direction if needed
                |     The option to have either the nearest solution or all
                |     solutions
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeatures
                | objects.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_project = com_object

    @property
    def direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction() As HybridShapeDirection
                | 
                |     Returns or sets the projection direction.
                | 
                |     Example: This example retrieves in Dir the direction for the Project hybrid
                |     shape feature.
                | 
                |      Dim Dir As Reference
                |      Set Dir = Project.Direction

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_project.Direction)

    @direction.setter
    def direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_project.Direction = direction.com_object

    @property
    def elem_to_project(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToProject() As Reference
                | 
                |     Returns or sets the element to project.This element can be a point or a
                |     curve.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge,
                |     BiDimFeatEdge or Vertex.
                | 
                |     Example: This example retrieves in Elem the element to project for the
                |     Project hybrid shape feature.
                | 
                |      Dim Elem As Reference
                |      Set Elem = Project.ElemToProject

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_project.ElemToProject)

    @elem_to_project.setter
    def elem_to_project(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_project.ElemToProject = reference_element.com_object

    @property
    def extrapolation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtrapolationMode() As long
                | 
                |     Returns or sets the extrapolation mode. The extrapolation mode is overriden
                |     when the solution type is 'Nearest solution' (0) or when the extrapolation mode
                |     being set is 'None' (0), otherwise the method fails. Role: None (0), Tangency
                |     (1) or Curvature (2).
                | 
                |     Example: This example retrieves in ExtrapolMode the solution type for the
                |     Project hybrid shape feature.
                | 
                |      Dim ExtrapolMode As long
                |      Set ExtrapolMode = Project.ExtrapolationMode

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_project.ExtrapolationMode

    @extrapolation_mode.setter
    def extrapolation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_project.ExtrapolationMode = value

    @property
    def maximum_deviation_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDeviationValue() As double
                | 
                |     Sets or Gets the maximum deviation allowed for smoothing
                |     operation.
                |     Sets in distance unit, it corresponds to the radius of a pipe around the
                |     input curve in which the result is allowed to be. This value must be set in SI
                |     unit (m).
                | 
                |     Example: This example retrieves in DeviationValue the maximum deviation
                |     value for the Project hybrid shape feature.
                | 
                |      Dim DeviationValue As CATIALength
                |      Set DeviationValue = Project.MaximumDeviationValue

        :return: float
        :rtype: float
        """

        return self.hybrid_shape_project.MaximumDeviationValue

    @maximum_deviation_value.setter
    def maximum_deviation_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_project.MaximumDeviationValue = value

    @property
    def normal(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Normal() As boolean
                | 
                |     Returns or sets the direction option. Role: To define the type of
                |     projection. Normal is set to TRUE if the projection is a normal
                |     projection.Otherwise, the projection is defined along a specified
                |     direction.
                | 
                |     Example: This example retrieves in NormalOption the support for the Project
                |     hybrid shape feature.
                | 
                |      Dim NormalOption As boolean
                |      Set NormalOption = Project.Normal

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_project.Normal

    @normal.setter
    def normal(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_project.Normal = value

    @property
    def smoothing_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothingType() As long
                | 
                |     Sets or Gets Smoothing Type.
                |     Role: Smoothing type
                |     : 0 -> No Smoothing
                |     : 2 -> G1 Smoothing : Enhance current continuity to tangent continuity
                |     : 3 -> G2 Smoothing : Enhance current continuity to curvature continuity
                | 
                |     Example: This example retrieves in SType the smoothing type for the Project
                |     hybrid shape feature.
                | 
                |      Dim SType As long
                |      Set SType = Project.SmoothingType

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_project.SmoothingType

    @smoothing_type.setter
    def smoothing_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_project.SmoothingType = value

    @property
    def solution_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolutionType() As long
                | 
                |     Returns or sets the solution type. When the solution type being set is 'All
                |     solutions' (1), the extrapolation mode gets overriden to 'None' (0). Role: All
                |     solutions (1) or Nearest solution (0) (only nearest projection is kept when
                |     more than one solution is possible).
                | 
                |     Example: This example retrieves in SolType the solution type for the
                |     Project hybrid shape feature.
                | 
                |      Dim SolType As long
                |      Set SolType = Project.SolutionType

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_project.SolutionType

    @solution_type.setter
    def solution_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_project.SolutionType = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support element.This element can be a plane or a
                |     surface.
                |     Sub-element(s) supported (see Boundary object): Face, TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example: This example retrieves in SupportElem the support for the Project
                |     hybrid shape feature.
                | 
                |      Dim SupportElem As Reference
                |      Set SupportElem = Project.Support

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_project.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_project.Support = reference_support.com_object

    @property
    def p_3d_smoothing(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property p3DSmoothing() As boolean
                | 
                |     Returns or sets the '3D Smoothing' option.
                |     Role: To activate or not the 3D smoothing option Available only for tangent or curvature
                |     smoothing type TRUE : Smoothing performed without specifying support FALSE : Smoothing performed
                |     with specific support
                | 
                |     Example: This example retrieves in 3DSmoothingOption the support for the
                |     Project hybrid shape feature.
                | 
                |      Dim 3DSmoothingOption As boolean
                |      Set 3DSmoothingOption = Project.p3DSmoothing

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_project.p3DSmoothing

    @p_3d_smoothing.setter
    def p_3d_smoothing(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_project.p3DSmoothing = value

    def __repr__(self):
        return f'HybridShapeProject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.navigator_interfaces.annotated_views import AnnotatedViews
from pycatia.navigator_interfaces.group import Group
from pycatia.navigator_interfaces.marker_3Ds import Marker3Ds
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Distance(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Distance
                | 
                | Represents the Distance object.
                | The Distance object is a specification of a distance computation between
                | products or groups of products.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.distance = com_object

    @property
    def accuracy(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Accuracy() As double
                | 
                |     Returns or sets the accuracy value for the computation.
                | 
                |     The accuracy value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the accuracy value of NewDistance
                |              Distance.
                |             
                | 
                |             Dim AccuracyValue As double
                |             AccuracyValue = NewDistance.Accuracy
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the accuracy value of NewDistance
                |                 Distance.
                |                 
                | 
                |                 NewDistance.Accuracy = 10.

        :return: float
        :rtype: float
        """

        return self.distance.Accuracy

    @accuracy.setter
    def accuracy(self, value: float):
        """
        :param float value:
        """

        self.distance.Accuracy = value

    @property
    def annotated_views(self) -> AnnotatedViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnnotatedViews() As AnnotatedViews (Read Only)
                | 
                |     Returns the AnnotatedViews collection of the distance.
                | 
                |     Example:
                | 
                |              This example retrieves the AnnotatedViews collection of
                |              NewDistance Distance.
                |             
                | 
                |             Dim TheAnnotatedViewsList As AnnotatedViews
                |             Set TheAnnotatedViewsList = NewDistance.AnnotatedViews

        :return: AnnotatedViews
        :rtype: AnnotatedViews
        """

        return AnnotatedViews(self.distance.AnnotatedViews)

    @property
    def computation_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ComputationType() As CatDistanceComputationType
                | 
                |     Returns or sets the computation type for the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the computation type of NewDistance
                |              Distance.
                |             
                | 
                |             Dim ComputationType As CatDistanceComputationType
                |             ComputationType = NewDistance.ComputationType
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the computation type of NewDistance
                |                 Distance.
                |                 
                | 
                |                 NewDistance.ComputationType = CatDistanceComputationTypeInsideOne

        :return: int
        :rtype: int
        """

        return self.distance.ComputationType

    @computation_type.setter
    def computation_type(self, value: int):
        """
        :param int value:
        """

        self.distance.ComputationType = value

    @property
    def first_group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstGroup() As Group
                | 
                |     Returns or sets the first group used by the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the first group of NewDistance
                |              Distance.
                |             
                | 
                |             Dim FirstGroup As Group
                |             Set FirstGroup = NewDistance.FirstGroup
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the first  group of NewDistance
                |                 Distance.
                |                 
                | 
                |                 Dim FirstGroup As Group
                |                 NewDistance.FirstGroup = FirstGroup

        :return: Group
        :rtype: Group
        """

        return Group(self.distance.FirstGroup)

    @first_group.setter
    def first_group(self, value: Group):
        """
        :param Group value:
        """

        self.distance.FirstGroup = value

    @property
    def first_product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstProduct() As Product (Read Only)
                | 
                |     Returns the product belonging to the first group that realizes the minimum
                |     distance.
                | 
                |     Example:
                | 
                |              This example retrieves the first product involved in the
                |              NewDistance Distance.
                |             
                | 
                |             Dim AProduct As Product
                |             Set AProduct = NewDistance.FirstProduct

        :return: Product
        :rtype: Product
        """

        return Product(self.distance.FirstProduct)

    @property
    def is_defined(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IsDefined() As long (Read Only)
                | 
                |     Returns a diagnosis on the distance.
                | 
                |     The diagnosis can take two values:
                | 
                |         = 0: the distance is undefined (for example only one product) and the results are invalid.
                |         = 1: the distance is defined and all results are valid. 
                | 
                |     Example:
                | 
                |              This example retrieves the diagnosis on NewDistance
                |              Distance.
                |             
                | 
                |             If NewDistance.IsDefined = 1 Then

        :return: int
        :rtype: int
        """

        return self.distance.IsDefined

    @property
    def marker_3ds(self) -> Marker3Ds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker3Ds() As Marker3Ds (Read Only)
                | 
                |     Returns the Marker3Ds collection of the distance.
                | 
                |     Example:
                | 
                |              This example retrieves the Marker3Ds collection of NewDistance
                |              Distance.
                |             
                | 
                |             Dim TheMarker3DsList As Marker3Ds
                |             Set TheMarker3DsList = NewDistance.Marker3Ds

        :return: Marker3Ds
        :rtype: Marker3Ds
        """

        return Marker3Ds(self.distance.Marker3Ds)

    @property
    def maximum_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDistance() As double
                | 
                |     Returns or sets the maximum distance value for the computation (valid only
                |     for band analysis).
                | 
                |     The maximum distance value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the maximum distance value of
                |              NewDistance Distance.
                |             
                | 
                |             Dim MaximumValue As double
                |             MaximumValue = NewDistance.MaximumDistance
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the maximum distance value of
                |                 NewDistance Distance.
                |                 
                | 
                |                 NewDistance.MaximumDistance = 10.

        :return: float
        :rtype: float
        """

        return self.distance.MaximumDistance

    @maximum_distance.setter
    def maximum_distance(self, value: float):
        """
        :param float value:
        """

        self.distance.MaximumDistance = value

    @property
    def measure_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MeasureType() As CatDistanceMeasureType
                | 
                |     Returns or sets the type of distance that will be
                |     calculated.
                | 
                |     Example:
                | 
                |              The first example retrieves the type of NewDistance
                |              Distance.
                |             
                | 
                |             Dim MeasureType As CatDistanceMeasureType
                |             MeasureType = NewDistance.MeasureType
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the Type of NewDistance
                |                 Distance.
                |                 
                | 
                |                 NewDistance.MeasureType = CatDistanceMeasureTypeMinimum

        :return: int
        :rtype: int
        """

        return self.distance.MeasureType

    @measure_type.setter
    def measure_type(self, value: int):
        """
        :param int value:
        """

        self.distance.MeasureType = value

    @property
    def minimum_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MinimumDistance() As double
                | 
                |     Returns or sets the minimum distance value for the computation (valid only
                |     for band analysis).
                | 
                |     The minimum distance value must be greater than 0.
                | 
                |     Example:
                | 
                |              The first example retrieves the minimum distance value of
                |              NewDistance Distance.
                |             
                | 
                |             Dim MinimumValue As double
                |             MinimumValue = NewDistance.MinimumDistance
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the minimum distance value of
                |                 NewDistance Distance.
                |                 
                | 
                |                 NewDistance.MinimumDistance = 10.

        :return: float
        :rtype: float
        """

        return self.distance.MinimumDistance

    @minimum_distance.setter
    def minimum_distance(self, value: float):
        """
        :param float value:
        """

        self.distance.MinimumDistance = value

    @property
    def second_group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondGroup() As Group
                | 
                |     Returns or sets the second group used by the computation.
                | 
                |     Example:
                | 
                |              The first example retrieves the second group of NewDistance
                |              Distance.
                |             
                | 
                |             Dim SecondGroup As Group
                |             Set SecondGroup = NewDistance.SecondGroup
                |             
                | 
                | 
                |             
                | 
                |                 The second example sets the second group of NewDistance
                |                 Distance.
                |                 
                | 
                |                 Dim SecondGroup As Group
                |                 NewDistance.SecondGroup = SecondGroup

        :return: Group
        :rtype: Group
        """

        return Group(self.distance.SecondGroup)

    @second_group.setter
    def second_group(self, value: Group):
        """
        :param Group value:
        """

        self.distance.SecondGroup = value

    @property
    def second_product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondProduct() As Product (Read Only)
                | 
                |     Returns the product belonging to the second group that realizes the minimum
                |     distance.
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates in the NewDistance
                |              Distance.
                |             
                | 
                |             Dim AProduct As Product
                |             Set AProduct = NewDistance.SecondProduct

        :return: Product
        :rtype: Product
        """

        return Product(self.distance.SecondProduct)

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Value() As double (Read Only)
                | 
                |     Returns the distance value.
                | 
                |     Example:
                | 
                |              This example retrieves the value of NewDistance
                |              Distance.
                |             
                | 
                |             Dim MinimumValue As double
                |             MinimumValue = NewDistance.Value

        :return: float
        :rtype: float
        """

        return self.distance.Value

    def compute(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Compute()
                | 
                |     Computes the distance.
                | 
                |     Example:
                | 
                |              This example computes the distance of NewDistance
                |              Distance.
                |             
                | 
                |             NewDistance.Compute

        :return: None
        :rtype: None
        """
        return self.distance.Compute()

    def get_first_point_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstPointCoordinates(CATSafeArrayVariant
                | oCoordinates)
                | 
                |     Retrieves the coordinates of the point belonging to the first product,
                |     which realizes the distance.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The coordinates of the point
                | 
                |                 oCoordinates(0) is the X coordinate
                |                 oCoordinates(1) is the Y coordinate
                |                 oCoordinates(2) is the Z coordinate 
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates of the first point in
                |              NewDistance Distance.
                |             
                | 
                |             Dim Coordinates (2)
                |             NewDistance.GetFirstPointCoordinates Coordinates

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_first_point_coordinates'
        vba_code = """
        Public Function get_first_point_coordinates(distance)
            Dim oCoordinates (2)
            distance.GetFirstPointCoordinates oCoordinates
            get_first_point_coordinates = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_point_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondPointCoordinates(CATSafeArrayVariant
                | oCoordinates)
                | 
                |     Retrieves the coordinates of the point belonging to the second product,
                |     which realizes the distance.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             The coordinates of the point
                | 
                |                 oCoordinates(0) is the X coordinate
                |                 oCoordinates(1) is the Y coordinate
                |                 oCoordinates(2) is the Z coordinate 
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates of the first point in
                |              NewDistance Distance.
                |             
                | 
                |             Dim Coordinates (2)
                |             NewDistance.GetSecondPointCoordinates Coordinates

        :return: None
        :rtype: None
        """

        vba_function_name = 'get_second_point_coordinates'
        vba_code = """
        Public Function get_second_point_coordinates(distance)
            Dim oCoordinates (2)
            distance.GetSecondPointCoordinates oCoordinates
            get_second_point_coordinates = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Distance(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeIntersection(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeIntersection
                | 
                | Represents the hybrid shape intersection feature object.
                | Role: To access the data of the hybrid shape intersection object. This data
                | includes:
                | 
                |     The first element to intersect
                |     The second element to intersect
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_intersection = com_object

    @property
    def element1(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Element1() As Reference
                | 
                |     Returns or sets the first element to intersect.
                |     Sub-element(s) supported (see Boundary object): Face, TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example:
                |         This example retrieves in FirstElem the first element to intersect for
                |         the Intersection hybrid shape feature.
                | 
                |          Dim FirstElem As Reference
                |          Set FirstElem = Intersection.Element1

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_intersection.Element1)

    @element1.setter
    def element1(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_intersection.Element1 = reference_element.com_object

    @property
    def element2(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Element2() As Reference
                | 
                |     Returns or sets the second element to intersect.
                |     Sub-element(s) supported (see Boundary object): Face, TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example:
                |         This example retrieves in SecondElem the second element to intersect
                |         for the Intersection hybrid shape feature.
                | 
                |          Dim SecondElem As Reference
                |          Set SecondElem = Intersection.Element2

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_intersection.Element2)

    @element2.setter
    def element2(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_intersection.Element2 = reference_element.com_object

    @property
    def extend_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtendMode() As long
                | 
                |     Returns or sets the ExtendMode flag for intersect.
                | 
                |     Example:
                |         This example retrieves in ExtendMode the ExtendMode to intersect for
                |         the Intersection hybrid shape feature.
                | 
                |          Dim ExtendMode As Reference
                |          Set ExtendMode = Intersection.ExtendMode
                |          ExtendMode is 0 when both "Extend Linear Supposr for intersection" are
                |          unchecked
                |          ExtendMode is 1 when "Extend Linear Supposr for intersection" for
                |          First Element is checked and for Second Element is
                |          unchecked
                |          ExtendMode is 2 when "Extend Linear Supposr for intersection" for
                |          First Element is unchecked and for Second Element is
                |          checked
                |          ExtendMode is 3 when both "Extend Linear Supposr for intersection" are
                |          checked

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_intersection.ExtendMode

    @extend_mode.setter
    def extend_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_intersection.ExtendMode = value

    @property
    def extrapolate_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtrapolateMode() As boolean
                | 
                |     Returns or sets the ExtrapolateMode flag for intersect.
                | 
                |     Example:
                |         This example retrieves in ExtrapolateMode the ExtrapolateMode to
                |         intersect for the Intersection hybrid shape feature.
                | 
                |          Dim ExtrapolateMode As Reference
                |          Set ExtrapolateMode = Intersection.ExtrapolateMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_intersection.ExtrapolateMode

    @extrapolate_mode.setter
    def extrapolate_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_intersection.ExtrapolateMode = value

    @property
    def intersect_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IntersectMode() As boolean
                | 
                |     Returns or sets the IntersectMode flag for intersect.
                | 
                |     Example:
                |         This example retrieves in IntersectMode the IntersectMode to intersect
                |         for the Intersection hybrid shape feature.
                | 
                |          Dim IntersectMode As Reference
                |          Set IntersectMode = Intersection.IntersectMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_intersection.IntersectMode

    @intersect_mode.setter
    def intersect_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_intersection.IntersectMode = value

    @property
    def point_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PointType() As long
                | 
                |     Returns or sets the PointType flag for intersect.
                | 
                |     Example:
                |         This example retrieves in PointType the PointType to intersect for the
                |         Intersection hybrid shape feature.
                | 
                |          Dim PointType As Reference
                |          Set PointType = Intersection.PointType

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_intersection.PointType

    @point_type.setter
    def point_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_intersection.PointType = value

    @property
    def solid_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolidMode() As boolean
                | 
                |     Returns or sets the SolidMode flag for intersect.
                | 
                |     Example:
                |         This example retrieves in SolidMode the SolidMode to intersect for the
                |         Intersection hybrid shape feature.
                | 
                |          Dim SolidMode As Reference
                |          Set SolidMode = Intersection.SolidMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_intersection.SolidMode

    @solid_mode.setter
    def solid_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_intersection.SolidMode = value

    def __repr__(self):
        return f'HybridShapeIntersection(name="{ self.name }")'
